# -*- coding: utf-8 -*-
"""
Debuggie - это набор инструментов для сбора и анализа отладочной информации об функционировании удалённой системы.

Набор включает в себя:

    Middleware, собирающую отладочную информацию
    Viewie - CLI-утилиту, предназначенную для просмотра дампов отладочной информации
    API для отладочного вывода информации из кода отлаживаемых приложений

Установка
---------

    Пакет устанавливается стандартным способом:

    .. code-block:: py

        pip install debuggie

    .. info:: Для работы пакета требуется m3.core.json.M3JSONEncoder

Подключение
-----------

    .. code-block:: py

        # ===========
        # settings.py
        # ===========

        INSTALLED_APPS = (
            ...,
            "debuggie",
            ...
        )

        MIDDLEWARE_CLASSES = (
            ...,
            'django.contrib.sessions.middleware.SessionMiddleware',
            'django.contrib.auth.middleware.AuthenticationMiddleware',
            "debuggie.Debuggie",
            ...
        )

        # функция, предоставляющая информацию о системе
        DEBUGGIE_SYSTEM_INFO_CALLBACK = "package.module.function"

        # ===========
        # urls.py
        # ===========
        urlpatterns = patterns(
            ...,
            (r'^debug/', include('debuggie.urls')),
            ...
        )

    .. warning:: Debuggie middleware должна добавляться после SessionMiddleware и AuthenticationMiddleware, т.к. зависит от них!

Запись отладочной информации
----------------------------

1. Пользователь аутентифицируется в системе,
2. Указанием в адресной строке переходит на url <some_host>/debug
3. На открытой странице можно включать/выключать режим отладки, очистить дамп отладочной информации или загрузить его в виде .txt-файла.
   При этом ссылки на загрузку и очистку дампа появятся после того, как пользователь:
    1. Включит отладочный режим
    2. Совершит в системе какие либо действия
    3. Обновит страницу отладочного режима.

Просмотр файла дампа отладочной информации
------------------------------------------

Информация просматривается в терминале командой viewie <dump_file.txt>
Программа просмотра работает в интерактивном режиме и содержит встроенную справку
"""

from api import tell, Debuggie
